@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2023, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2024, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -572,6 +572,7 @@ public class LocaleNames_sl extends OpenListResourceBundle {
             { "bej", "bed\u017ea" },
             { "bem", "bemba" },
             { "bez", "benaj\u0161\u010dina" },
+            { "bgc", "harjan\u0161\u010dina" },
             { "bgn", "zahodnobalu\u010dij\u0161\u010dina" },
             { "bho", "bod\u017epuri" },
             { "bik", "bikolski jezik" },
@@ -597,7 +598,7 @@ public class LocaleNames_sl extends OpenListResourceBundle {
             { "chp", "\u010dipev\u0161\u010dina" },
             { "chr", "\u010deroke\u0161\u010dina" },
             { "chy", "\u010dejen\u0161\u010dina" },
-            { "ckb", "soranska kurd\u0161\u010dina" },
+            { "ckb", "osrednja kurd\u0161\u010dina" },
             { "clc", "\u010dilkotin\u0161\u010dina" },
             { "cop", "kopt\u0161\u010dina" },
             { "crg", "mi\u010dif\u0161\u010dina" },
@@ -1178,7 +1179,6 @@ public class LocaleNames_sl extends OpenListResourceBundle {
             { "type.ca.japanese", "japonski koledar" },
             { "type.cf.standard", "standardna oblika zapisa valute" },
             { "type.co.phonetic", "foneti\u010dno razvr\u0161\u010danje" },
-            { "type.co.reformed", "reformirano razvr\u0161\u010danje" },
             { "type.co.searchjl", "Iskanje po za\u010detnem soglasniku hangul" },
             { "type.co.standard", "Standardno razvr\u0161\u010danje" },
             { "type.ms.uksystem", "imperialni merski sistem" },
@@ -1198,8 +1198,6 @@ public class LocaleNames_sl extends OpenListResourceBundle {
             { "type.co.dictionary", "slovarsko razvr\u0161\u010danje" },
             { "type.co.traditional", "razvr\u0161\u010danje po tradicionalnem sistemu" },
             { "type.nu.traditional", "Tradicionalne \u0161tevilke" },
-            { "type.ca.islamic-rgsa", "islamski koledar ( Saudova Arabija, opazovalni)" },
-            { "type.ca.islamic-tbla", "islamski koledar (tabelarni, astronomska epoha)" },
             { "type.ca.islamic-civil", "islamski civilni koledar" },
             { "type.ca.islamic-umalqura", "islamski koledar Umm al-Qura" },
             { "type.ca.ethiopic-amete-alem", "etiopsko ametsko alemski koledar" },
